.. _stsynphot_config_file:

stsynphot's Default Configuration File
**************************************

To customize this, copy it to your ``$HOME/.astropy/config/stsynphot.cfg``,
uncomment the relevant configuration item(s), and insert your desired value(s).

.. generate_config:: stsynphot
